import requests
import json
import time
import os
import csv
import sys
import configparser
from os.path import expanduser
from pySmartDL import SmartDL
os.chdir(os.path.dirname(os.path.realpath(__file__)))
home=os.path.dirname(os.path.realpath(__file__))


def satmeta(sensor,geometry,target):
    if geometry !=None and os.path.isfile(geometry):
        footprint = {
        "type": "Polygon",
        "coordinates": []
            }
        f = open(geometry)
        for line in f:
            obj = json.loads(line)
            footprint['coordinates']=obj['features'][0]['geometry']['coordinates']
        params = {'footprint': json.dumps(footprint),'limit': 4000}
    else:
        params = {'limit': 4000}
    print("Getting token...")
    config=configparser.ConfigParser()
    config.read(os.path.join(expanduser("~"),".satellogic-config"))
    telluric_token=config.get('token','access_token')
    url = 'https://telluric.satellogic.com/v2/scenes/'
    header = { 'authorization' : telluric_token}
    print("Requesting scene...")
    r = requests.get(url, params=params,headers=header)
    if r.status_code != 200:
        raise ValueError("Telluric response error: %s" %r.text)
    response=r.json()
    for scenes in response['results']:
        if sensor =='macro':
            try:
                if 'macro_cube' in scenes['scene_id']:
                    scene_id=scenes['scene_id']
                    params = {'scene_id': scene_id}
                    r = requests.get(url, params=params,headers=header)
                    response = r.json()
                    print('')
                    print('Processing '+str(response['results'][0]['scene_id']))
                    for items in response['results'][0]['attachments']:
                        filename=items['file_name']
                        itemurl=items['url']
                        locname=response['results'][0]['metadata']['location_requested_name']
                        if not os.path.exists(os.path.join(target,scene_id,"metadata")):
                            os.makedirs(os.path.join(target,scene_id,"metadata"))
                        if not os.path.isfile(os.path.join(target,scene_id,"metadata",filename)):
                            print("Downloading "+str(os.path.join(scene_id,filename)))
                            dest=os.path.join(target,scene_id,"metadata",filename)
                            url=itemurl
                            try:
                                obj = SmartDL(url, dest)
                                obj.start()
                                path = obj.get_dest()
                            except Exception as e:
                                pass
                        else:
                            print("File already exists skipping "+str(os.path.join(scene_id,filename)))
            except Exception as e:
                print(e)
        elif sensor == 'micro':
            try:
                if 'micro' in scenes['scene_id']:
                    scene_id=scenes['scene_id']
                    params = {'scene_id': scene_id}
                    r = requests.get(url, params=params,headers=header)
                    response = r.json()
                    print('')
                    print('Processing '+str(response['results'][0]['scene_id']))
                    for items in response['results'][0]['attachments']:
                        filename=items['file_name']
                        itemurl=items['url']
                        locname=response['results'][0]['metadata']['location_requested_name']
                        if not os.path.exists(os.path.join(target,scene_id,"metadata")):
                            os.makedirs(os.path.join(target,scene_id,"metadata"))
                        if not os.path.isfile(os.path.join(target,scene_id,"metadata",filename)):
                            print("Downloading "+str(os.path.join(scene_id,filename)))
                            dest=os.path.join(target,scene_id,"metadata",filename)
                            url=itemurl
                            try:
                                obj = SmartDL(url, dest)
                                obj.start()
                                path = obj.get_dest()
                            except Exception as e:
                                pass
                        else:
                            print("File already exists skipping "+str(os.path.join(scene_id,filename)))
            except Exception as e:
                print(e)

# satmeta(sensor='micro',
#     geometry=r"C:\Users\samapriya\Downloads\westcoast.geojson",
#     target=r"C:\planet_demo\hyper")



import ee
import csv
import os
import json
import time
from kml2ee import kml2coord
os.chdir(os.path.dirname(os.path.realpath(__file__)))
try:
    ee.Initialize()
except Exception, e:
    print 'Authenticate Earth Engine first and rerun program'
    time.sleep(2)
    os.system('earthengine authenticate')

src=os.path.dirname(os.path.realpath(__file__))

l=[]

for items in os.listdir(src):
    if items.endswith('.csv'):
        input_file=csv.DictReader(open(os.path.join(src,items)))
        for rows in input_file:
            l.append(rows['id'])

def intersect(start,end,geojson,operator,output):
    with open(output, 'wb') as csvfile:
        writer = csv.DictWriter(csvfile, fieldnames=['type', 'id','#items'],
                                delimiter=',')
        writer.writeheader()
    i=1
    for items in l:
        print('Processing '+str(i)+' of '+str(len(l)))
        i=i+1
        try:
            typ = ee.data.getInfo(items)['type']
        except Exception as e:
            pass
        try:
            if geojson.endswith('.geojson'):
                with open(geojson) as aoi:
                    aoi_resp = json.load(aoi)
                    aoi_geom = ee.Geometry.Polygon(aoi_resp['features'
                            ][0]['geometry']['coordinates'])
                    boundbox = aoi_geom.bounds()
            elif geojson.endswith('.json'):
                with open (geojson) as aoi:
                    aoi_resp=json.load(aoi)
                    aoi_geom=ee.Geometry.Polygon(aoi_resp['config'][0]['config']['coordinates'])
                    boundbox=aoi_geom.bounds()
            elif geojson.endswith('.kml'):
                getcoord=kml2coord(geojson)
                aoi_geom=ee.Geometry.Polygon(getcoord)
                boundbox=aoi_geom.bounds()
        except Exception as e:
            print('Could not parse geometry')
            print(e)
        if str(typ) == 'Image' and operator == 'bb':
            try:
                userCollection = \
                    ee.ImageCollection([items]).filterBounds(boundbox).filterDate(start,
                        end)
                length = userCollection.size().getInfo()
                if int(length) == 0:
                    pass
                    #print 'Geometry does not intersect collection '+str(items)
                else:
                    #print 'Total images in filtered collection: '+str(items) +' of size '+ str(length)
                    with open(output, 'a') as csvfile:
                        writer = csv.writer(csvfile, delimiter=',',
                                lineterminator='\n')
                        writer.writerow([str(typ),str(items),str(length)])
                    csvfile.close()
            except Exception as e:
                print('Check on Collection failed becaused '+str(e))
        elif str(typ) == 'Image' and operator == None:

            try:
                userCollection =ee.ImageCollection([items]).filterBounds(aoi_geom).filterDate(start,
                        end)
                length = userCollection.size().getInfo()
                if int(length) == 0:
                    pass
                    #print 'Geometry does not intersect collection '+str(items)
                else:
                    #print 'Total images in filtered collection: '+str(items) +' of size '+ str(length)
                    with open(output, 'a') as csvfile:
                        writer = csv.writer(csvfile, delimiter=',',
                                lineterminator='\n')
                        writer.writerow([str(typ),str(items),str(length)])
                    csvfile.close()
            except Exception as e:
                print('Check on Collection failed becaused '+str(e))
        elif typ == 'ImageCollection' and operator == 'bb':
            try:
                userCollection = \
                    ee.ImageCollection(items).filterBounds(boundbox).filterDate(start,
                        end)
                length = userCollection.size().getInfo()
                if int(length) == 0:
                    pass
                    #print 'Geometry does not intersect collection '+str(items)
                else:
                    #print 'Total images in filtered collection: '+str(items) +' of size '+ str(length)
                    with open(output, 'a') as csvfile:
                        writer = csv.writer(csvfile, delimiter=',',
                                lineterminator='\n')
                        writer.writerow([str(typ),str(items),str(length)])
                    csvfile.close()
            except Exception as e:
                print('Check on Collection failed becaused '+str(e))
        elif typ == 'ImageCollection' and operator == None:
            try:
                userCollection = \
                    ee.ImageCollection(items).filterBounds(aoi_geom).filterDate(start,
                        end)
                length = userCollection.size().getInfo()
                if int(length) == 0:
                    pass
                    #print 'Geometry does not intersect collection '+str(items)
                else:
                    #print 'Total images in filtered collection: '+str(items) +' of size '+ str(length)
                    with open(output, 'a') as csvfile:
                        writer = csv.writer(csvfile, delimiter=',',
                                lineterminator='\n')
                        writer.writerow([str(typ),str(items),str(length)])
                    csvfile.close()
            except Exception as e:
                print('Check on Collection failed becaused '+str(e))
    print('')
    print('Report with Intersects Exported to '+str(output))
#exp(start='2000-01-01',end='2018-12-31',geojson=r'C:\planet_demo\terra\terra.geojson',operator=None,output=r'C:\planet_demo\terr.csv')



import configparser
import os
import getpass
from os.path import expanduser
from gbdxtools import Interface
Config = configparser.ConfigParser()
username= raw_input("Enter your username: ")
password=getpass.getpass('Enter your password: ')
with open(os.path.join(expanduser("~"),".gbdx-config"),'w') as cfgfile:
    Config.add_section('gbdx')
    Config.set('gbdx','user_name',username)
    Config.set('gbdx','user_password', password)
    Config.write(cfgfile)
    cfgfile.close()
try:
    gbdx=Interface()
    print('Authenticated')
except Exception as e:
    print(e)



import geojson
import json
import geopandas as gpd
import os
import sys
os.chdir(os.path.dirname(os.path.realpath(__file__)))
from kml2ee import kml2coord
from shapely.geometry import shape
path=os.path.dirname(os.path.realpath(__file__))
if path not in sys.path:
    sys.path.insert(0, path)

def coord2wkt(coord):
    o = {
   "coordinates": coord,
   "type": "Polygon"}
    geom = shape(o)
    s = json.dumps(o)
    g1 = geojson.loads(s)
    g2 = shape(g1)
    return (str(g2))

def shp2cord(folder):
    for items in os.listdir(folder):
        if items.endswith('.shp'):
            inD = gpd.read_file(os.path.join(folder,items))
            #Reproject to EPSG 4326
            try:
                data_proj = inD.copy()
                data_proj['geometry'] = data_proj['geometry'].to_crs(epsg=4326)
                for items, rows in data_proj.iterrows():
                    return str(rows['geometry'])
            except Exception, e:
                print e
        elif items.endswith('geojson'):
            with open(os.path.join(folder,items)) as aoi:
                aoi_resp = json.load(aoi)
                aoi_geom = aoi_resp['features'][0]['geometry']['coordinates']
                return coord2wkt(aoi_geom)
        elif items.endswith('.json'):
            with open (os.path.join(folder,items)) as aoi:
                aoi_resp=json.load(aoi)
                aoi_geom=aoi_resp['config'][0]['config']['coordinates']
                return coord2wkt(aoi_geom)
        elif items.endswith('.kml'):
            getcoord=kml2coord(os.path.join(folder,items))
            return coord2wkt(getcoord)

def shp2cordfile(items):
    if items.endswith('.shp'):
        inD = gpd.read_file(items)
        #Reproject to EPSG 4326
        try:
            data_proj = inD.copy()
            data_proj['geometry'] = data_proj['geometry'].to_crs(epsg=4326)
            for items, rows in data_proj.iterrows():
                return str(rows['geometry'])
        except Exception, e:
            print e
    elif items.endswith('geojson'):
        with open(items) as aoi:
            aoi_resp = json.load(aoi)
            aoi_geom = aoi_resp['features'][0]['geometry']['coordinates']
            return coord2wkt(aoi_geom)
    elif items.endswith('.json'):
        with open (items) as aoi:
            aoi_resp=json.load(aoi)
            aoi_geom=aoi_resp['config'][0]['config']['coordinates']
            return coord2wkt(aoi_geom)
    elif items.endswith('.kml'):
        getcoord=kml2coord(items)
        return coord2wkt(getcoord)
#shp2cord(folder=r'C:\planet_demo\testmos')

#     o = {
#    "coordinates": [[[23.314208, 37.768469], [24.039306, 37.768469], [24.039306, 38.214372], [23.314208, 38.214372], [23.314208, 37.768469]]],
#    "type": "Polygon"
# }



import configparser
import os
import getpass
import requests
from os.path import expanduser
Config = configparser.ConfigParser()
username= raw_input("Enter your username: ")
password=getpass.getpass('Enter your password: ')
url = 'https://auth.telluric.satellogic.com/api-token-auth/'
payload = {'username':username,'password':password}
print("Getting token...")
r = requests.post(url, data=payload)
if r.status_code != 200:
    raise ValueError("Telluric response error: %s" %r.text)
telluric_token="JWT "+r.json()['token']
with open(os.path.join(expanduser("~"),".satellogic-config"),'w') as cfgfile:
    Config.add_section('satellogic')
    Config.set('satellogic','user_name',username)
    Config.set('satellogic','user_password', password)
    Config.add_section('token')
    Config.set('token','access_token',telluric_token)
    Config.write(cfgfile)
    cfgfile.close()
print('Access token saved')



#!/usr/bin/python
# -*- coding: utf-8 -*-
from __future__ import print_function
import ee
import json
import csv
import subprocess
import os
pth = os.path.dirname(os.path.realpath(__file__))
try:
    ee.Initialize()
except Exception as e:
    print('Authenticate Earth Engine first and rerun program')
    time.sleep(2)
    os.system('earthengine authenticate')

def ee_report(output):
    with open(output, 'wb') as csvfile:
        writer = csv.DictWriter(csvfile, fieldnames=['title', 'id'],
                                delimiter=',')
        writer.writeheader()
    a = subprocess.check_output('earthengine ls', shell=True)
    b = subprocess.check_output('earthengine ls -l -r ' + a, shell=True)
    try:
        for item in b.split('\n'):
            a = item.replace('[', '').replace(']', '').split()
            header = a[0]
            tail = a[1]
            if header == 'ImageCollection':
                collc = ee.ImageCollection(tail)
                print('Processing Image Collection ' + str(tail))
                with open(output, 'a') as csvfile:
                    writer = csv.writer(csvfile, delimiter=',',
                            lineterminator='\n')
                    writer.writerow([str(tail).split('/')[-1], tail])
                csvfile.close()
            elif header == 'Image':
                collc = ee.Image(tail)
                print('Processing Image ' + str(tail))
                with open(output, 'a') as csvfile:
                    writer = csv.writer(csvfile, delimiter=',',
                            lineterminator='\n')
                    writer.writerow([str(tail).split('/')[-1], tail])
                csvfile.close()
            else:
                pass
    except Exception:
        return 'worked'


ee_report(output=os.path.join(pth, 'myasset.csv'))

##if __name__ == '__main__':
##    ee_report(None)



#!/usr/bin/env python

import multiprocessing
import os
import sys
import time
import csv
import requests

########################################################################
class MultiProcDownloader(object):
    """
    Downloads urls with Python's multiprocessing module
    """

    #----------------------------------------------------------------------
    def __init__(self, urls):
        """ Initialize class with list of urls """
        self.urls = urls

    #----------------------------------------------------------------------
    def run(self):
        """
        Download the urls and waits for the processes to finish
        """
        jobs = []
        for url in self.urls:
            process = multiprocessing.Process(target=self.worker, args=(url,))
            jobs.append(process)
            process.start()
        for job in jobs:
            job.join()

    #----------------------------------------------------------------------
    def worker(self, url):
        """
        The target method that the process uses tp download the specified url
        """
        try:
            basefolder=url.split('=')[0]
            foldname=url.split('=')[1]
            filename=url.split('=')[2].split('[')[0]
            msg = "Starting download of %s" % os.path.join(foldname,filename)
            if not os.path.exists(os.path.join(basefolder,foldname)):
                os.makedirs(os.path.join(basefolder,foldname))
            os.chdir(os.path.join(basefolder,foldname))
            url=url.split('[')[1]
            #print(os.path.join(basefolder,foldname,filename))
            if not os.path.isfile(os.path.join(basefolder,foldname,filename)):
                r = requests.get(url, stream=True)
                time.sleep(1)
                if r.status_code==200:
                    print msg, multiprocessing.current_process().name
                    with open(os.path.join(basefolder,foldname,filename), 'wb') as f:
                        for chunk in r.iter_content(chunk_size=1024 * 1024):
                            if chunk: # filter out keep-alive new chunks
                                f.write(chunk)
            else:
                print("File already exists skipping "+str(filename))
        except Exception as e:
            print(e)
            # print('Issues with file: '+str(filename))

def funct(local,final):
    if not os.path.exists(final):
        os.makedirs(final)
    os.chdir(final)
    urls=[]
    with open(local) as csvfile:
        reader = csv.DictReader(csvfile)
        for row in reader:
            urls.append(str(final)+'='+str(row['scene_id'])+'='+str(row['filename'])+'['+row['download_url'])
    downloader = MultiProcDownloader(urls)
    downloader.run()

#----------------------------------------------------------------------
if __name__ == "__main__":
    funct(local=os.path.normpath(sys.argv[1]),final=os.path.normpath(sys.argv[2]))
    # downloader = MultiProcDownloader(urls)
    # downloader.run()



#!/usr/bin/python
# -*- coding: utf-8 -*-
import ee
import os
import time
import re
try:
    ee.Initialize()
except Exception, e:
    print 'Authenticate Earth Engine first and rerun program'
    time.sleep(2)
    os.system('earthengine authenticate')


##great alphanumeric sorting https://stackoverflow.com/questions/2669059/how-to-sort-alpha-numeric-set-in-python

def sorted_nicely(l):
    """ Sort the given iterable in the way that humans expect."""

    convert = lambda text: (int(text) if text.isdigit() else text)
    alphanum_key = lambda key: [convert(c) for c in re.split('([0-9]+)'
                                , key)]
    return sorted(l, key=alphanum_key)


def imgexp(collection):
    typ = ee.data.getInfo(collection)['type']
    print typ + ' ' + str(collection)
    if typ == 'Image':
        info = ee.Image(collection).bandTypes().getInfo()
        b16uint = []
        b32uint = []
        b16sint = []
        b8uint = []
        fl = []
        for (key, value) in \
            ee.Image(collection).bandTypes().getInfo().items():
            if value['precision'] == 'float':
                fl.append(str(key))
            elif value['precision'] == 'int':
                if value['min'] == 0 and value['max'] == 255:
                    b8uint.append(str(key))
                if value['min'] == -32768 and value['max'] == 32767:
                    b16sint.append(str(key))
                if value['min'] == 0 and value['max'] == 65535:
                    b16uint.append(str(key))
                if value['min'] == 0 and value['max'] == 4294967295:
                    b32uint.append(str(key))
        if len(b8uint) > 0:
            print '8 bit unsigned integer bands ' + str(b8uint)
        if len(b16uint) > 0:
            print '16 bit unsigned integer bands ' \
                + str(sorted_nicely(b16uint))
        if len(b16sint) > 0:
            print '16 bit signed integer bands ' \
                + str(sorted_nicely(b16sint))
        if len(b32uint) > 0:
            print '32 bit unsigned integer bands ' \
                + str(sorted_nicely(b32uint))
        if len(fl) > 0:
            print 'Bands of type Float ' + str(fl)
    elif typ == 'ImageCollection':
        info = \
            ee.Image(ee.ImageCollection(collection).first()).getInfo()
        b16uint = []
        b32uint = []
        b16sint = []
        b8uint = []
        fl = []
        for (key, value) in \
            ee.Image(ee.ImageCollection(collection).first()).bandTypes().getInfo().items():
            if value['precision'] == 'float':
                fl.append(str(key))
            elif value['precision'] == 'int':

                if value['min'] == 0 and value['max'] == 255:
                    b8uint.append(str(key))
                if value['min'] == -32768 and value['max'] == 32767:
                    b16sint.append(str(key))
                if value['min'] == 0 and value['max'] == 65535:
                    b16uint.append(str(key))
                if value['min'] == 0 and value['max'] == 4294967295:
                    b32uint.append(str(key))
        if len(b8uint) > 0:
            print '8 bit unsigned integer bands ' + str(b8uint)
        if len(b16uint) > 0:
            print '16 bit unsigned integer bands ' \
                + str(sorted_nicely(b16uint))
        if len(b16sint) > 0:
            print '16 bit signed integer bands ' \
                + str(sorted_nicely(b16sint))
        if len(b32uint) > 0:
            print '32 bit unsigned integer bands ' \
                + str(sorted_nicely(b32uint))
        if len(fl) > 0:
            print 'Bands of type Float ' + str(fl)


# imgexp(collection='USGS/SRTMGL1_003')



#!/usr/bin/python
# -*- coding: utf-8 -*-
import os
import csv

os.chdir(os.path.dirname(os.path.realpath(__file__)))
src = os.path.dirname(os.path.realpath(__file__))


def idsearch(mname):
    for items in os.listdir(src):
        if items.endswith('.csv'):
            input_file = csv.DictReader(open(os.path.join(src, items)))
            for rows in input_file:
                if mname.upper().lower() in str(rows['title'
                        ]).upper().lower():
                    try:
                        print str(rows['title']) + ' >> ' \
                            + str(rows['id'])
                    except Exception, e:
                        print e


# idsearch(mname='Belem')



from xml.etree import ElementTree
from shapely.geometry import Polygon, Point
import json

poly_table = []

def kml2coord(filename):
    data = open(filename)
    tree = ElementTree.parse(data)
    namespace = tree.getroot().tag[1:].split("}")[0]
    placemarks = tree.findall(".//{%s}Placemark" % namespace)
    for p in placemarks:
        for d in p.findall(".//{%s}Data" % namespace):
            if d.attrib.get('name') == 'OBJECTID':
                name = d.find('.//{%s}value' % namespace).text
        coord_text = p.find('.//{%s}coordinates' % namespace).text
        coord_pairs = coord_text.split(' ')
        coords = [z.split(',')[0:2] for z in coord_pairs]
        for x in coords:
            try:
                poly_table.append([float(x[0]),float(x[1])])
            except:
                pass
        return poly_table



#!/usr/bin/python
# -*- coding: utf-8 -*-
import subprocess
import os
import json
os.chdir(os.path.dirname(os.path.realpath(__file__)))
path = os.path.dirname(os.path.realpath(__file__))
template = {'type': 'FeatureCollection', 'features': [{'type': 'Feature'
            , 'properties': {}, 'geometry': {'type': 'Polygon',
            'coordinates': []}}]}


def ddownload(
    infile,
    item,
    asset,
    dirc,
    start,
    end,
    cmin,
    cmax,
    ):
    try:
        if infile.endswith('.geojson'):
            st = start
            ed = end
            ccovermin = cmin
            ccovermax = cmax
            subprocess.call('planet data download --item-type '
                            + str(item) + ' --geom ' + '"'
                            + infile
                            + '"' + ' --date acquired gt '
                            + str(st) + ' --date acquired lt '
                            + str(ed) + ' --range cloud_cover gt '
                            + str(ccovermin)
                            + ' --range cloud_cover lt '
                            + str(ccovermax) + ' --asset-type '
                            + str(asset) + ' --dest ' + '"' + dirc
                            + '"', shell=True)            
        elif infile.endswith('.json'):           
            with open(infile) as aoi:
                aoi_resp = json.load(aoi)
                for items in aoi_resp['config']:
                    if start == None and end == None:
                        if items['type'] == 'DateRangeFilter' \
                            and items['field_name'] == 'acquired':
                            st = items['config']['gte'].split('T')[0]
                            ed = items['config']['lte'].split('T')[0]
                    else:
                        st = start
                        ed = end
                    if items['type'] == 'GeometryFilter':

                        # print(items['config']['coordinates'])

                        template['features'][0]['geometry']['coordinates'
                                ] = items['config']['coordinates']
                        with open(os.path.join(path, 'bounds.geojson'), 'w'
                                  ) as f:
                            f.write(json.dumps(template))
                    if cmin == None and cmax == None:
                        if items['type'] == 'RangeFilter' \
                            and items['field_name'] == 'cloud_cover':
                            ccovermin = items['config']['gte']
                            ccovermax = items['config']['lte']
                    else:
                        ccovermin = cmin
                        ccovermax = cmax
                if os.path.exists(os.path.join(path, 'bounds.geojson')):
                    subprocess.call('planet data download --item-type '
                                    + str(item) + ' --geom ' + '"'
                                    + os.path.join(path, 'bounds.geojson')
                                    + '"' + ' --date acquired gt '
                                    + str(st) + ' --date acquired lt '
                                    + str(ed) + ' --range cloud_cover gt '
                                    + str(ccovermin)
                                    + ' --range cloud_cover lt '
                                    + str(ccovermax) + ' --asset-type '
                                    + str(asset) + ' --dest ' + '"' + dirc
                                    + '"', shell=True)
    except Exception, e:
        print e



import ee
import os
import json
import time
import sys
import ast
from kml2ee import kml2coord
os.chdir(os.path.dirname(os.path.realpath(__file__)))
try:
    ee.Initialize()
except Exception, e:
    print 'Authenticate Earth Engine first and rerun program'
    time.sleep(2)
    os.system('earthengine authenticate')


def exp(collection,folderpath,start,end,
    geojson,bandnames,operator,typ):
    #typ = ee.data.getInfo(collection)['type']
    bandnames = ast.literal_eval(bandnames)
    try:
        if geojson.endswith('.geojson'):
            with open(geojson) as aoi:
                aoi_resp = json.load(aoi)
                aoi_geom = ee.Geometry.Polygon(aoi_resp['features'
                        ][0]['geometry']['coordinates'])
                boundbox = aoi_geom.bounds()
        elif geojson.endswith('.json'):
            with open (geojson) as aoi:
                aoi_resp=json.load(aoi)
                aoi_geom=ee.Geometry.Polygon(aoi_resp['config'][0]['config']['coordinates'])
                boundbox=aoi_geom.bounds()
        elif geojson.endswith('.kml'):
            getcoord=kml2coord(geojson)
            aoi_geom=ee.Geometry.Polygon(getcoord)
            boundbox=aoi_geom.bounds()            
    except Exception as e:
        print('Could not parse geometry')
        print(e)        
    if typ == 'image' and operator == 'bb':
        userCollection = \
            ee.ImageCollection(collection).select(bandnames)
        clipname = os.path.basename(geojson).split('.')[0]
        fileName = str(collection).split('/')[-1] + '_' + str(clipname) \
            + '_bb'
        firstband = ee.Image(collection).bandNames().getInfo()[0]
        scale = \
            int(ee.Image(collection).select(firstband).projection().nominalScale().getInfo())
        task = ee.batch.Export.image.toDrive(
            image=ee.Image(collection).clip(boundbox),
            description=fileName,
            folder=folderpath,
            maxPixels=1e13,
            region=boundbox.getInfo()['coordinates'][0],
            scale=scale,
            )
        task.start()
        print 'Finished creating export task'
        print ''
    elif typ == 'image' and operator == None:
        userCollection = \
            ee.ImageCollection(collection).select(bandnames)
        clipname = os.path.basename(geojson).split('.')[0]
        fileName = str(collection).split('/')[-1] + '_' + str(clipname)
        firstband = ee.Image(collection).bandNames().getInfo()[0]
        scale = \
            int(ee.Image(collection).select(firstband).projection().nominalScale().getInfo())
        task = ee.batch.Export.image.toDrive(
            image=ee.Image(collection).clip(aoi_geom),
            description=fileName,
            folder=folderpath,
            maxPixels=1e13,
            region=aoi_geom.getInfo()['coordinates'][0],
            scale=scale,
            )
        task.start()
        print 'Finished creating export task'
        print ''
    elif typ == 'collection' and operator == 'bb':
        userCollection = \
            ee.ImageCollection(collection).filterBounds(aoi_geom).filterDate(start,
                end).select(bandnames)
        clipname = os.path.basename(geojson).split('.')[0]
        imageList = \
            ee.List(userCollection.toList(userCollection.size().add(1)))
        length = userCollection.size().getInfo()
        if int(length) == 0:
            print 'No images found exiting export function'
            sys.exit()
        else:
            print 'Total images in filtered collection: ' + str(length)

            def exportImage(img):
                fileName = ee.String(img.get('system:index')).getInfo()
                firstband = img.bandNames().getInfo()[0]
                scale = \
                    int(img.select(firstband).projection().nominalScale().getInfo())

                # get geometry of image

                task = ee.batch.Export.image.toDrive(
                    image=img.clip(boundbox),
                    description=fileName + '_' + str(clipname) + '_bb',
                    folder=folderpath,
                    maxPixels=1e13,
                    region=boundbox.getInfo()['coordinates'][0],
                    scale=scale,
                    )
                task.start()

            index = 0
            while index < int(length):
                print 'Export #: ' + str(index + 1) + ' of ' \
                    + str(length)
                img2export = ee.Image(imageList.get(index))
                exportImage(img2export)
                index = index + 1

                # time.sleep(10)

            print 'Finished creating export task'
            print ''
    elif typ == 'collection' and operator == None:
        userCollection = \
            ee.ImageCollection(collection).filterBounds(aoi_geom).filterDate(start,
                end).select(bandnames)
        clipname = os.path.basename(geojson).split('.')[0]
        imageList = \
            ee.List(userCollection.toList(userCollection.size().add(1)))
        length = userCollection.size().getInfo()
        if int(length) == 0:
            print 'No images found exiting export function'
            sys.exit()
        else:
            print 'Total images in filtered collection: ' + str(length)

            def exportImage(img):
                fileName = ee.String(img.get('system:index')).getInfo()
                firstband = img.bandNames().getInfo()[0]
                scale = \
                    int(img.select(firstband).projection().nominalScale().getInfo())

                # get geometry of image

                task = ee.batch.Export.image.toDrive(
                    image=img.clip(aoi_geom),
                    description=fileName + '_' + str(clipname),
                    folder=folderpath,
                    maxPixels=1e13,
                    region=aoi_geom.getInfo()['coordinates'][0],
                    scale=scale,
                    )
                task.start()

            index = 0
            while index < int(length):
                print 'Export #: ' + str(index + 1) + ' of ' \
                    + str(length)
                img2export = ee.Image(imageList.get(index))
                exportImage(img2export)
                index = index + 1

                # time.sleep(10)

            print 'Finished creating export task'
            print ''



import configparser
import os
import json
import subprocess
import requests
from os.path import expanduser
config=configparser.ConfigParser()

url = "https://geobigdata.io/auth/v1/validate_token"

def validate():
    try:
        config.read(os.path.join(expanduser("~"),".gbdx-config"))
        at=json.loads(config.get('gbdx_token','json'))
        accesstoken=at['access_token']
        headers = {
        'Authorization': "Bearer "+accesstoken,
        }
        response = requests.request("GET", url, headers=headers).json()
        print('username: '+str(response['username']))
        print('user id: '+str(response['user_id']))
        print('account id: '+str(response['account_id']))
        print('id: '+str(response['id']))
        print('role: '+str(response['role']))
        print('client_id: '+str(response['client_id']))
        print('Account level: '+str(response['account_level']))
    except Exception as e:
        print('access_token not found')
        subprocess.call('python autenticator.py', shell=True)





import argparse,sys,os,time,csv,json,subprocess
from xml.dom import minidom
os.chdir(os.path.dirname(os.path.realpath(__file__)))
def metadata(asset,mf,mfile,errorlog,directory=None):
    if directory is None:
        if asset == 'PSO': # PS OrthoTile Analytic
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "orbit","provider","instrument","satellite_id","tile_id",
                                                          "number_of_bands", "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover","incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle",
                                                          "radiometric_scale_factor","reflectance_coefficient_b1",
                                                          "reflectance_coefficient_b2","reflectance_coefficient_b3",
                                                          "reflectance_coefficient_b4"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = filename.split('_x')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    ps4band=xmldoc.getElementsByTagName('ps:EarthObservationMetaData')[0]
                    eopfilename = xmldoc.getElementsByTagName('eop:identifier')[0].firstChild.data
                    productType = xmldoc.getElementsByTagName('eop:productType')[0].firstChild.data
                    orbit = xmldoc.getElementsByTagName('eop:orbitType')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[1].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    tile_id=xmldoc.getElementsByTagName("ps:tileId")[0].firstChild.data
                    bands=xmldoc.getElementsByTagName("ps:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("ps:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("ps:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("ps:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("ps:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("ps:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psb=xmldoc.getElementsByTagName("ps:bandNumber")[0].firstChild.data
                    psb1=xmldoc.getElementsByTagName("ps:bandNumber")[1].firstChild.data
                    psb3=xmldoc.getElementsByTagName("ps:bandNumber")[2].firstChild.data
                    psb4=xmldoc.getElementsByTagName("ps:bandNumber")[3].firstChild.data
                    psbrad=xmldoc.getElementsByTagName("ps:radiometricScaleFactor")[0].firstChild.data
                    psb1ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[0].firstChild.data
                    psb2ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[1].firstChild.data
                    psb3ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[2].firstChild.data
                    psb4ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[3].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("ps:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("ps:spaceCraftViewAngle")[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([eopfilename,epoch,productType,orbit,provider,instrument,satellite_id,tile_id,bands,epsg_code,resampling_kernel
                                         ,number_rows,number_columns,format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),format(float(pssca),'.4f')
                                         ,psbrad,format(float(psb1ref),'.8f'),format(float(psb2ref),'.8f'),format(float(psb3ref),'.8f'),
                                         format(float(psb4ref),'.8f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([infilename])
                    csvfile.close()

        elif asset == 'PSO_DN': #PS OrthoTile Analytic Derivative DN
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "orbit","provider","instrument","satellite_id","tile_id",
                                                          "number_of_bands", "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover","incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = filename.split('_x')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    ps4band=xmldoc.getElementsByTagName('ps:EarthObservationMetaData')[0]
                    eopfilename = xmldoc.getElementsByTagName('eop:identifier')[0].firstChild.data
                    productType = xmldoc.getElementsByTagName('eop:productType')[0].firstChild.data
                    orbit = xmldoc.getElementsByTagName('eop:orbitType')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[1].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    tile_id=xmldoc.getElementsByTagName("ps:tileId")[0].firstChild.data
                    bands=xmldoc.getElementsByTagName("ps:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("ps:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("ps:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("ps:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("ps:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("ps:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("ps:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("ps:spaceCraftViewAngle")[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([eopfilename,epoch,productType,orbit,provider,instrument,satellite_id,tile_id,bands,epsg_code,resampling_kernel
                                         ,number_rows,number_columns,format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),format(float(pssca),'.4f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'PSO_V': #PS OrthoTile Analytic Derivative Visual
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "orbit","provider","instrument","satellite_id","tile_id",
                                                          "number_of_bands", "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover","incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = filename.split('_x')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    ps4band=xmldoc.getElementsByTagName('ps:EarthObservationMetaData')[0]
                    eopfilename = xmldoc.getElementsByTagName('eop:identifier')[0].firstChild.data
                    productType = xmldoc.getElementsByTagName('eop:productType')[0].firstChild.data
                    orbit = xmldoc.getElementsByTagName('eop:orbitType')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[1].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    tile_id=xmldoc.getElementsByTagName("ps:tileId")[0].firstChild.data
                    bands=xmldoc.getElementsByTagName("ps:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("ps:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("ps:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("ps:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("ps:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("ps:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("ps:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("ps:spaceCraftViewAngle")[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([eopfilename,epoch,productType,orbit,provider,instrument,satellite_id,tile_id,bands,epsg_code,resampling_kernel
                                         ,number_rows,number_columns,format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),format(float(pssca),'.4f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'PS4B': #PS 4 Band Scene Derivative Analytic
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "orbit","provider","instrument","satellite_id",
                                                          "number_of_bands", "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover","incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle",
                                                          "radiometric_scale_factor","reflectance_coefficient_b1",
                                                          "reflectance_coefficient_b2","reflectance_coefficient_b3",
                                                          "reflectance_coefficient_b4"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = filename.split('_x')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    ps4band=xmldoc.getElementsByTagName('ps:EarthObservationMetaData')[0]
                    eopfilename = xmldoc.getElementsByTagName('eop:identifier')[0].firstChild.data
                    productType = xmldoc.getElementsByTagName('eop:productType')[0].firstChild.data
                    orbit = xmldoc.getElementsByTagName('eop:orbitType')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[1].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    bands=xmldoc.getElementsByTagName("ps:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("ps:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("ps:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("ps:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("ps:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("ps:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psb=xmldoc.getElementsByTagName("ps:bandNumber")[0].firstChild.data
                    psb1=xmldoc.getElementsByTagName("ps:bandNumber")[1].firstChild.data
                    psb3=xmldoc.getElementsByTagName("ps:bandNumber")[2].firstChild.data
                    psb4=xmldoc.getElementsByTagName("ps:bandNumber")[3].firstChild.data
                    psbrad=xmldoc.getElementsByTagName("ps:radiometricScaleFactor")[0].firstChild.data
                    psb1ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[0].firstChild.data
                    psb2ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[1].firstChild.data
                    psb3ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[2].firstChild.data
                    psb4ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[3].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("ps:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("ps:spaceCraftViewAngle")[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([eopfilename,epoch,productType,orbit,provider,instrument,satellite_id,bands,epsg_code,resampling_kernel
                                         ,number_rows,number_columns,format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),format(float(pssca),'.4f')
                                         ,psbrad,format(float(psb1ref),'.8f'),format(float(psb2ref),'.8f'),format(float(psb3ref),'.8f'),
                                         format(float(psb4ref),'.8f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'PS4B_DN': #PS 4 Band Scene Derivative DN
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "orbit","provider","instrument","satellite_id",
                                                          "number_of_bands", "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover","incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = filename.split('_x')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    ps4band=xmldoc.getElementsByTagName('ps:EarthObservationMetaData')[0]
                    eopfilename = xmldoc.getElementsByTagName('eop:identifier')[0].firstChild.data
                    productType = xmldoc.getElementsByTagName('eop:productType')[0].firstChild.data
                    orbit = xmldoc.getElementsByTagName('eop:orbitType')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[1].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    bands=xmldoc.getElementsByTagName("ps:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("ps:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("ps:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("ps:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("ps:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("ps:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psb=xmldoc.getElementsByTagName("ps:bandNumber")[0].firstChild.data
                    psb1=xmldoc.getElementsByTagName("ps:bandNumber")[1].firstChild.data
                    psb3=xmldoc.getElementsByTagName("ps:bandNumber")[2].firstChild.data
                    psb4=xmldoc.getElementsByTagName("ps:bandNumber")[3].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("ps:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("ps:spaceCraftViewAngle")[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([eopfilename,epoch,productType,orbit,provider,instrument,satellite_id,bands,epsg_code,resampling_kernel
                                         ,number_rows,number_columns,format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),format(float(pssca),'.4f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'PS3B': #PS 3 Band Scene Derivative Analytic Work from here
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "orbit","provider","instrument","satellite_id",
                                                          "number_of_bands", "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover","incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle",
                                                          "radiometric_scale_factor","reflectance_coefficient_b1",
                                                          "reflectance_coefficient_b2","reflectance_coefficient_b3"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = filename.split('_x')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    ps4band=xmldoc.getElementsByTagName('ps:EarthObservationMetaData')[0]
                    eopfilename = xmldoc.getElementsByTagName('eop:identifier')[0].firstChild.data
                    productType = xmldoc.getElementsByTagName('eop:productType')[0].firstChild.data
                    orbit = xmldoc.getElementsByTagName('eop:orbitType')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[1].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    bands=xmldoc.getElementsByTagName("ps:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("ps:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("ps:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("ps:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("ps:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("ps:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psb=xmldoc.getElementsByTagName("ps:bandNumber")[0].firstChild.data
                    psb1=xmldoc.getElementsByTagName("ps:bandNumber")[1].firstChild.data
                    psb3=xmldoc.getElementsByTagName("ps:bandNumber")[2].firstChild.data
                    psbrad=xmldoc.getElementsByTagName("ps:radiometricScaleFactor")[0].firstChild.data
                    psb1ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[0].firstChild.data
                    psb2ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[1].firstChild.data
                    psb3ref=xmldoc.getElementsByTagName("ps:reflectanceCoefficient")[2].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("ps:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("ps:spaceCraftViewAngle")[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([eopfilename,epoch,productType,orbit,provider,instrument,satellite_id,bands,epsg_code,resampling_kernel
                                         ,number_rows,number_columns,format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),format(float(pssca),'.4f')
                                         ,psbrad,format(float(psb1ref),'.8f'),format(float(psb2ref),'.8f'),format(float(psb3ref),'.8f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'PS3B_DN': #PS 3 Band Scene Derivative DN
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "orbit","provider","instrument","satellite_id",
                                                          "number_of_bands", "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover","incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = filename.split('_x')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    ps4band=xmldoc.getElementsByTagName('ps:EarthObservationMetaData')[0]
                    eopfilename = xmldoc.getElementsByTagName('eop:identifier')[0].firstChild.data
                    productType = xmldoc.getElementsByTagName('eop:productType')[0].firstChild.data
                    orbit = xmldoc.getElementsByTagName('eop:orbitType')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[1].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    bands=xmldoc.getElementsByTagName("ps:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("ps:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("ps:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("ps:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("ps:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("ps:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psb=xmldoc.getElementsByTagName("ps:bandNumber")[0].firstChild.data
                    psb1=xmldoc.getElementsByTagName("ps:bandNumber")[1].firstChild.data
                    psb3=xmldoc.getElementsByTagName("ps:bandNumber")[2].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("ps:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("ps:spaceCraftViewAngle")[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([eopfilename,epoch,productType,orbit,provider,instrument,satellite_id,bands,epsg_code,resampling_kernel
                                         ,number_rows,number_columns,format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),format(float(pssca),'.4f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'PS3B_V': #PS 3 Band Scene Derivative Visual
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "orbit","provider","instrument","satellite_id",
                                                          "number_of_bands", "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover","incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = filename.split('_x')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    ps4band=xmldoc.getElementsByTagName('ps:EarthObservationMetaData')[0]
                    eopfilename = xmldoc.getElementsByTagName('eop:identifier')[0].firstChild.data
                    productType = xmldoc.getElementsByTagName('eop:productType')[0].firstChild.data
                    orbit = xmldoc.getElementsByTagName('eop:orbitType')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[1].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    bands=xmldoc.getElementsByTagName("ps:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("ps:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("ps:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("ps:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("ps:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("ps:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psb=xmldoc.getElementsByTagName("ps:bandNumber")[0].firstChild.data
                    psb1=xmldoc.getElementsByTagName("ps:bandNumber")[1].firstChild.data
                    psb3=xmldoc.getElementsByTagName("ps:bandNumber")[2].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("ps:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("ps:spaceCraftViewAngle")[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([eopfilename,epoch,productType,orbit,provider,instrument,satellite_id,bands,epsg_code,resampling_kernel
                                         ,number_rows,number_columns,format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),format(float(pssca),'.4f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'REO':
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:              
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "tile_id","order_id","orbit","provider",
                                                          "instrument","satellite_id","number_of_bands",
                                                          "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover",
                                                          "incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle",
                                                          "radiometric_scale_factor"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder,filename)
                fsp=filename.split("_x")[0]
                try:
                    xmldoc=minidom.parse(infilename)
                    re=xmldoc.getElementsByTagName("re:EarthObservationMetaData")[0]
                    id_no=xmldoc.getElementsByTagName("eop:identifier")[0].firstChild.data
                    productType=xmldoc.getElementsByTagName("eop:productType")[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    tile_id=xmldoc.getElementsByTagName("re:tileId")[0].firstChild.data
                    order_id=xmldoc.getElementsByTagName("re:orderId")[0].firstChild.data
                    orbit=xmldoc.getElementsByTagName("eop:orbitType")[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data.split('-')[0]
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    number_of_bands=xmldoc.getElementsByTagName("re:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("re:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("re:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("re:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("re:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("re:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("re:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("re:spaceCraftViewAngle")[0].firstChild.data
                    psrad=xmldoc.getElementsByTagName("re:radiometricScaleFactor")[0].firstChild.data
                    date_time = acquisition.split("T")[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern)))*1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([id_no,epoch,str(productType),str(tile_id),str(order_id),
                                         str(orbit),str(provider),str(instrument),str(satellite_id),
                                         number_of_bands,epsg_code,resampling_kernel,number_rows,number_columns,
                                         format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),
                                         format(float(pssca),'.4f'),format(float(psrad),'.18f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                            writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'REO_V':
            folder = mf
            path, dirs, files = next(os.walk(folder))
            file_count = len(files)
            i=1
            with open(mfile,'wb') as csvfile:              
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "product_type",
                                                          "tile_id","order_id","orbit","provider",
                                                          "instrument","satellite_id","number_of_bands",
                                                          "epsg_code","resampling_kernel",
                                                          "number_of_rows","number_of_columns","gsd","cloud_cover",
                                                          "incidence_angle",
                                                          "sun_azimuth","sun_elevation","azimuth_angle","spacecraft_angle",
                                                          "radiometric_scale_factor"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder,filename)
                fsp=filename.split("_x")[0]
                try:
                    xmldoc=minidom.parse(infilename)
                    re=xmldoc.getElementsByTagName("re:EarthObservationMetaData")[0]
                    id_no=xmldoc.getElementsByTagName("eop:identifier")[0].firstChild.data
                    productType=xmldoc.getElementsByTagName("eop:productType")[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('eop:acquisitionDate')[0].firstChild.data
                    tile_id=xmldoc.getElementsByTagName("re:tileId")[0].firstChild.data
                    order_id=xmldoc.getElementsByTagName("re:orderId")[0].firstChild.data
                    orbit=xmldoc.getElementsByTagName("eop:orbitType")[0].firstChild.data
                    provider=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data.split('-')[0]
                    instrument=xmldoc.getElementsByTagName("eop:shortName")[0].firstChild.data
                    satellite_id=xmldoc.getElementsByTagName("eop:serialIdentifier")[0].firstChild.data
                    number_of_bands=xmldoc.getElementsByTagName("re:numBands")[0].firstChild.data
                    epsg_code=xmldoc.getElementsByTagName("re:epsgCode")[0].firstChild.data
                    resampling_kernel=xmldoc.getElementsByTagName("re:resamplingKernel")[0].firstChild.data
                    number_rows=xmldoc.getElementsByTagName("re:numRows")[0].firstChild.data
                    number_columns=xmldoc.getElementsByTagName("re:numColumns")[0].firstChild.data
                    gsd=xmldoc.getElementsByTagName("re:rowGsd")[0].firstChild.data
                    cloud=xmldoc.getElementsByTagName("opt:cloudCoverPercentage")[0].firstChild.data
                    psia=xmldoc.getElementsByTagName("eop:incidenceAngle")[0].firstChild.data
                    psilaz=xmldoc.getElementsByTagName("opt:illuminationAzimuthAngle")[0].firstChild.data
                    psilelv=xmldoc.getElementsByTagName("opt:illuminationElevationAngle")[0].firstChild.data
                    psaz=xmldoc.getElementsByTagName("re:azimuthAngle")[0].firstChild.data
                    pssca=xmldoc.getElementsByTagName("re:spaceCraftViewAngle")[0].firstChild.data
                    psrad=xmldoc.getElementsByTagName("re:radiometricScaleFactor")[0].firstChild.data
                    date_time = acquisition.split("T")[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern)))*1000
                    print("Processing "+str(i)+" of "+str(file_count))
                    i=i+1
                    with open(mfile,'a') as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([id_no,epoch,str(productType),str(tile_id),str(order_id),
                                         str(orbit),str(provider),str(instrument),str(satellite_id),
                                         number_of_bands,epsg_code,resampling_kernel,number_rows,number_columns,
                                         format(float(gsd),'.2f'),format(float(cloud),'.2f'),format(float(psia),'.4f'),
                                         format(float(psilaz),'.2f'),format(float(psilelv),'.2f'),format(float(psaz),'.2f'),
                                         format(float(pssca),'.4f'),format(float(psrad),'.18f')])
                    csvfile.close()
                except Exception as e:
                    print(infilename)
                    print(e)
                    with open(errorlog,'a') as csvfile:
                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                            writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'DGMS':
            folder = mf
            with open(mfile, 'wb') as csvfile:
                writer = csv.DictWriter(csvfile, fieldnames=['id_no', 'satName', 'prodID', 'catID', 'satID', 'stripID', 'numBands', 'cloudcover', 'system:time_start', 'sunaz', 'sunelv', 'sataz', 'satelv', 'absfB1', 'absfB2',
                 'absfB3', 'absfB4', 'absfB5', 'absfB6', 'absfB7', 'absfB8', 'effbwB1', 'effbwB2', 'effbwB3', 'effbwB4', 'effbwB5', 'effbwB6', 'effbwB7', 'effbwB8'], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                print filename
                infilename = os.path.join(folder, filename)
                fsp = filename.split('.')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    pid = xmldoc.getElementsByTagName('PRODUCTORDERID')[0].firstChild.data
                    cid = xmldoc.getElementsByTagName('PRODUCTCATALOGID')[0].firstChild.data
                    satid = xmldoc.getElementsByTagName('SATID')[0].firstChild.data
                    stripid = xmldoc.getElementsByTagName('STRIPID')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('STARTTIME')[0].firstChild.data
                    cloud = xmldoc.getElementsByTagName('CLOUDCOVER')[0].firstChild.data
                    sunaz = xmldoc.getElementsByTagName('MEANSUNAZ')[0].firstChild.data
                    sunelv = xmldoc.getElementsByTagName('MEANSUNEL')[0].firstChild.data
                    sataz = xmldoc.getElementsByTagName('MEANSATAZ')[0].firstChild.data
                    satelv = xmldoc.getElementsByTagName('MEANSATEL')[0].firstChild.data
                    satelv = xmldoc.getElementsByTagName('MEANOFFNADIRVIEWANGLE')[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    if satid == 'QB02':
                        satname = 'QuickBird'
                        bands = 4
                        absfb1 = xmldoc.getElementsByTagName('ABSCALFACTOR')[0].firstChild.data
                        absfb2 = xmldoc.getElementsByTagName('ABSCALFACTOR')[1].firstChild.data
                        absfb3 = xmldoc.getElementsByTagName('ABSCALFACTOR')[2].firstChild.data
                        absfb4 = xmldoc.getElementsByTagName('ABSCALFACTOR')[3].firstChild.data
                        absfb5 = 0
                        absfb6 = 0
                        absfb7 = 0
                        absfb8 = 0
                        effbwb1 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[0].firstChild.data
                        effbwb2 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[1].firstChild.data
                        effbwb3 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[2].firstChild.data
                        effbwb4 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[3].firstChild.data
                        effbwb5 = 0
                        effbwb6 = 0
                        effbwb7 = 0
                        effbwb8 = 0
                    elif satid == 'GE01':
                        satname = 'Geoeye'
                        bands = 4
                        absfb1 = xmldoc.getElementsByTagName('ABSCALFACTOR')[0].firstChild.data
                        absfb2 = xmldoc.getElementsByTagName('ABSCALFACTOR')[1].firstChild.data
                        absfb3 = xmldoc.getElementsByTagName('ABSCALFACTOR')[2].firstChild.data
                        absfb4 = xmldoc.getElementsByTagName('ABSCALFACTOR')[3].firstChild.data
                        absfb5 = 0
                        absfb6 = 0
                        absfb7 = 0
                        absfb8 = 0
                        effbwb1 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[0].firstChild.data
                        effbwb2 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[1].firstChild.data
                        effbwb3 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[2].firstChild.data
                        effbwb4 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[3].firstChild.data
                        effbwb5 = 0
                        effbwb6 = 0
                        effbwb7 = 0
                        effbwb8 = 0
                    elif satid == 'WV02':
                        satname = 'WorldView-2'
                        bands = 8
                        absfb1 = xmldoc.getElementsByTagName('ABSCALFACTOR')[0].firstChild.data
                        absfb2 = xmldoc.getElementsByTagName('ABSCALFACTOR')[1].firstChild.data
                        absfb3 = xmldoc.getElementsByTagName('ABSCALFACTOR')[2].firstChild.data
                        absfb4 = xmldoc.getElementsByTagName('ABSCALFACTOR')[3].firstChild.data
                        absfb5 = xmldoc.getElementsByTagName('ABSCALFACTOR')[4].firstChild.data
                        absfb6 = xmldoc.getElementsByTagName('ABSCALFACTOR')[5].firstChild.data
                        absfb7 = xmldoc.getElementsByTagName('ABSCALFACTOR')[6].firstChild.data
                        absfb8 = xmldoc.getElementsByTagName('ABSCALFACTOR')[7].firstChild.data
                        effbwb1 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[0].firstChild.data
                        effbwb2 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[1].firstChild.data
                        effbwb3 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[2].firstChild.data
                        effbwb4 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[3].firstChild.data
                        effbwb5 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[4].firstChild.data
                        effbwb6 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[5].firstChild.data
                        effbwb7 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[6].firstChild.data
                        effbwb8 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[7].firstChild.data
                    else:
                        satname = 'WorldView-3'
                        bands = 8
                        absfb1 = xmldoc.getElementsByTagName('ABSCALFACTOR')[0].firstChild.data
                        absfb2 = xmldoc.getElementsByTagName('ABSCALFACTOR')[1].firstChild.data
                        absfb3 = xmldoc.getElementsByTagName('ABSCALFACTOR')[2].firstChild.data
                        absfb4 = xmldoc.getElementsByTagName('ABSCALFACTOR')[3].firstChild.data
                        absfb5 = xmldoc.getElementsByTagName('ABSCALFACTOR')[4].firstChild.data
                        absfb6 = xmldoc.getElementsByTagName('ABSCALFACTOR')[5].firstChild.data
                        absfb7 = xmldoc.getElementsByTagName('ABSCALFACTOR')[6].firstChild.data
                        absfb8 = xmldoc.getElementsByTagName('ABSCALFACTOR')[7].firstChild.data
                        effbwb1 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[0].firstChild.data
                        effbwb2 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[1].firstChild.data
                        effbwb3 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[2].firstChild.data
                        effbwb4 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[3].firstChild.data
                        effbwb5 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[4].firstChild.data
                        effbwb6 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[5].firstChild.data
                        effbwb7 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[6].firstChild.data
                        effbwb8 = xmldoc.getElementsByTagName('EFFECTIVEBANDWIDTH')[7].firstChild.data
                    print (
                     'ID_Name:', fsp)
                    print ('Satellite Name:', satname)
                    print ('Acquisition Date:', acquisition.split('T')[0])
                    print ('Product Order ID:', str(pid))
                    print ('Product Catalog ID:', str(cid))
                    print ('Satellite ID:', str(satid))
                    print ('Strip ID:', stripid)
                    print ('Number of Bands:', bands)
                    print ('Cloud Cover:', cloud[:4])
                    print ('Epoch Time:', epoch)
                    print ('Abscal Factor', absfb1)
                    print ('Abscal Factor', absfb2)
                    print ('Abscal Factor', absfb3)
                    print ('Abscal Factor', absfb4)
                    print ('Eff Bandwith', effbwb1)
                    print ('Eff Bandwith', effbwb2)
                    print ('Eff Bandwith', effbwb3)
                    print ('Eff Bandwith', effbwb4)
                    print ('Sun Elevation', format(float(sunelv), '.2f'))
                    print ('Sun Azimuth', format(float(sunaz), '.2f'))
                    print ('Sat Elevation', format(float(satelv), '.2f'))
                    print ('Sat Azimuth', format(float(sataz), '.2f'))
                    with open(mfile, 'a') as csvfile:
                        writer = csv.writer(csvfile, delimiter=',', lineterminator='\n')
                        writer.writerow([fsp, satname, pid, cid, satid, stripid, bands, format(float(cloud), '.2f'), epoch, format(float(sunaz), '.2f'), format(float(sunelv), '.2f'),
                         format(float(sataz), '.2f'), format(float(satelv), '.2f'), format(float(absfb1), '.6f'), format(float(absfb2), '.6f'), format(float(absfb3), '.6f'), format(float(absfb4), '.6f'),
                         format(float(absfb5), '.6f'), format(float(absfb6), '.6f'), format(float(absfb7), '.6f'), format(float(absfb8), '.6f'), format(float(effbwb1), '.6f'), format(float(effbwb2), '.6f'),
                         format(float(effbwb3), '.6f'), format(float(effbwb4), '.6f'), format(float(effbwb5), '.6f'), format(float(effbwb6), '.6f'), format(float(effbwb7), '.6f'), format(float(effbwb8), '.6f')])
                    csvfile.close()
                except Exception as e:
                    print infilename
                    print(e)
                    with open(errorlog, 'wb') as csvfile:
                        writer = csv.writer(csvfile, delimiter=',')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'DGP':
            folder = mf
            with open(mfile, 'wb') as csvfile:
                writer = csv.DictWriter(csvfile, fieldnames=['id_no', 'satName', 'prodID', 'catID', 'satID', 'stripID', 'numBands', 'cloudcover', 'system:time_start'], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                print filename
                infilename = os.path.join(folder, filename)
                fsp = filename.split('.')[0]
                try:
                    xmldoc = minidom.parse(infilename)
                    pid = xmldoc.getElementsByTagName('PRODUCTORDERID')[0].firstChild.data
                    cid = xmldoc.getElementsByTagName('PRODUCTCATALOGID')[0].firstChild.data
                    satid = xmldoc.getElementsByTagName('SATID')[0].firstChild.data
                    stripid = xmldoc.getElementsByTagName('STRIPID')[0].firstChild.data
                    acquisition = xmldoc.getElementsByTagName('STARTTIME')[0].firstChild.data
                    cloud = xmldoc.getElementsByTagName('CLOUDCOVER')[0].firstChild.data
                    date_time = acquisition.split('T')[0]
                    pattern = '%Y-%m-%d'
                    epoch = int(time.mktime(time.strptime(date_time, pattern))) * 1000
                    if satid == 'QB02':
                        satname = 'QuickBird'
                    elif satid == 'GE01':
                        satname = 'Geoeye'
                    elif satid == 'WV02':
                        satname = 'WorldView-2'
                    else:
                        satname = 'WorldView-3'
                    if satid == 'QB02':
                        bands = 1
                    elif satid == 'GE01':
                        bands = 1
                    elif satid == 'WV02':
                        bands = 1
                    else:
                        bands = 1
                    print (
                     'ID_Name:', fsp)
                    print ('Satellite Name:', satname)
                    print ('Acquisition Date:', acquisition.split('T')[0])
                    print ('Product Order ID:', str(pid))
                    print ('Product Catalog ID:', str(cid))
                    print ('Satellite ID:', str(satid))
                    print ('Strip ID:', stripid)
                    print ('Number of Bands:', bands)
                    print ('Cloud Cover:', cloud[:4])
                    print ('Epoch Time:', epoch)
                    with open(mfile, 'a') as csvfile:
                        writer = csv.writer(csvfile, delimiter=',', lineterminator='\n')
                        writer.writerow([fsp, satname, pid, cid, satid, stripid, bands, cloud[:4], epoch])
                    csvfile.close()
                except Exception as e:
                    print infilename
                    print(e)
                    with open(errorlog, 'wb') as csvfile:
                        writer = csv.writer(csvfile, delimiter=',')
                        writer.writerow([infilename])
                    csvfile.close()
        elif asset == 'PGCDEM': #PS OrthoTile Analytic Derivative DN
            folder = mf
            with open(mfile,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no", "system:time_start", "platform", "catId1","catId2", "noDataValue", "releaseVersion", "srcImg1","srcImg2","setsmVersion","resolution","bitdepth","acqDate","minelv","maxelv","units"], delimiter=',')
                writer.writeheader()
            with open(errorlog,'wb') as csvfile:
                writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
                writer.writeheader()
            for filename in os.listdir(folder):
                infilename = os.path.join(folder, filename)
                fsp = infilename#.split('_x')[0]
                with open(fsp,'r') as myfile:
                    a=myfile.readlines()
                    try:
                        demid=str(a).split('stripDemId = "')[1].split('v2.0";')[0]+"v20_dem"
                        platform=str(a).split('platform = "')[1].split('";')[0]
                        catId1 = str(a).split('catId1 = "')[1].split('";')[0]
                        catId2 = str(a).split('catId2 = "')[1].split('";')[0]
                        noDataValue = str(a).split('noDataValue = ')[1].split(';')[0]
                        date_time = str(a).split('stripCreationTime = ')[1].split('T')[0]
                        rls=str(a).split('releaseVersion = "')[1].split('";')[0]
                        sim=str(a).split('sourceImage1 = "')[1].split('";')[0]
                        sim2=str(a).split('sourceImage2 = "')[1].split('";')[0]
                        setv=str(a).split('setsmVersion = ')[1].split(';')[0]
                        rs=str(a).split('outputResolution = ')[1].split(';')[0]
                        bp=str(a).split('bitsPerPixel = ')[1].split(';')[0]
                        acq=str(a).split('acqDate = ')[1].split(';')[0]
                        minelv=str(a).split('minElevValue = ')[1].split(';')[0]
                        maxelv=str(a).split('maxElevValue = ')[1].split(';')[0]
                        units=str(a).split('horizontalCoordSysUnits = "')[1].split('";')[0]
                        pattern = '%Y-%m-%d'
                        epoch = int(time.mktime(time.strptime(date_time, pattern)))*1000
                        acqtime=int(time.mktime(time.strptime(acq, pattern)))*1000
                        print("DEM ID",demid)
                        print("Platform",platform)
                        print("Acquisition Time",acqtime)
                        print("Strip Creation Time",epoch)
                        print('CatID1',catId1)
                        print('CatID2',catId2)
                        print("noDataValue",noDataValue)
                        print("Release Version",rls)
                        print("SourceImage 1",sim)
                        print('SourceImage 2',sim2)
                        print('SETSM Version',setv)
                        print("BitsPerPixel",bp)
                        print("Unit",units)
                        print("Minimum Elevation",format(float(minelv),'.2f'))
                        print("Maximum Elevation",format(float(maxelv),'.2f'))
                        print("Output Resolution",format(float(rs),'.2f'))
                        with open(mfile,'a') as csvfile:
                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                            writer.writerow([demid,epoch,platform,catId1,catId2,noDataValue,rls,sim,sim2,setv,format(float(rs),'.2f'),bp,acqtime,format(float(minelv),'.2f'),format(float(maxelv),'.2f'),units])
                        csvfile.close()
                    except Exception as e:
                        print(infilename)
                        print(e)
                        with open(errorlog,'a') as csvfile:
                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                            writer.writerow([infilename])
                        csvfile.close()
    else: #PS 4 Band Scene Derivative DN
        folder = mf
        indir=directory
        mfile=mfile
        errorlog=errorlog
        try:
            subprocess.call("python sr_metadata.py PSR --indir "+'"'+indir+'" --mfile '+'"'+mfile+'" --folder '+'"'+folder+'" --errorlog '+'"'+errorlog+'"',shell=True)
        except Exception as e:
            print(e)



#!/usr/bin/python
# -*- coding: utf-8 -*-
import os
import csv
import shutil
from shutil import copyfile
from git import Repo
os.chdir(os.path.dirname(os.path.realpath(__file__)))
src = os.path.dirname(os.path.realpath(__file__))

# get os type

name = os.name

# set base folder names and paths

folder_name = 'eed'
pth = os.path.join(src, folder_name)

if name == 'nt':
    os.system('cls')
elif name == 'posix':
    os.system('clear')

if os.path.exists(pth):
    if name == 'nt':
        os.system('rmdir ' + '"' + pth + '" /s /q')
    elif name == 'posix':
        try:
            shutil.rmtree(pth)
        except:
            print 'Try using sudo privileges'

Repo.clone_from('https://github.com/samapriya/Earth-Engine-Datasets-List.git'
                , os.path.join(src, folder_name))

for items in os.listdir(os.path.join(src, folder_name)):
    if items.endswith('.csv'):
        copyfile(os.path.join(pth, items), os.path.join(src, items))
        with open(os.path.join(src, items)) as fp:
            reader = csv.reader(fp, delimiter=',')
            data = list(reader)
            row_count = len(data)
            print 'EE dataset updated and has ' + str(row_count) \
                + ' assets'



import configparser
import requests
import json
import os
import getpass
import subprocess
import csv
from os.path import expanduser
from multipath import shp2cord
from multipath import shp2cordfile
os.chdir(os.path.dirname(os.path.realpath(__file__)))
url = "https://geobigdata.io/catalog/v2/search"
config=configparser.ConfigParser()
config.read(os.path.join(expanduser("~"),".gbdx-config"))

def mxp(path,start,end,limit):
    try:
        config.read(os.path.join(expanduser("~"),".gbdx-config"))
        at=json.loads(config.get('gbdx_token','json'))
        accesstoken=at['access_token']
        start=str(start)+str('T12:00:00.000Z')
        end=str(end)+str('T12:00:00.000Z')
        if os.path.isfile(path):
            cd=shp2cordfile(path)
            payload= {"searchAreaWkt": cd,"startDate": start,"endDate": end,"limit":limit}
            payload=json.dumps(payload)
            headers = {
                'Content-Type': "application/json",
                'Authorization': "Bearer "+accesstoken,
                }
            response = requests.request("POST", url, data=payload, headers=headers).json()
            for key,value in response['stats']['typeCounts'].items():
                print('Processing '+str(key)+' : '+str(value))
            for items in response['results']:
                cat=items['properties']['catalogID']
                plat=items['properties']['sensorPlatformName']
                los=os.path.split(path)[0]
                print(os.path.join(los,plat))
                if not os.path.exists(os.path.join(los,plat)):
                    os.makedirs(os.path.join(los,plat))
                if not os.path.exists(os.path.join(los,plat,str(cat)+'_'+str(plat)+'.json')):
                    with open(os.path.join(los,plat,str(cat)+'_'+str(plat)+'.json'), 'w') as outfile:
                        json.dump(items['properties'], outfile)
                else:
                    print('File already Exists: SKIPPING')
    except Exception as e:
        print('access_token not found use pygbdx init')
        subprocess.call('python autenticator.py', shell=True)

#mxp(path=r'C:\planet_demo\imja\nola.geojson',start='2016-01-01',end='2018-01-01',limit=125)



import configparser
import os
import requests
from os.path import expanduser
from gbdxtools import Interface
Config = configparser.ConfigParser()
try:
    config=configparser.ConfigParser()
    config.read(os.path.join(expanduser("~"),".satellogic-config"))
    url = 'https://auth.telluric.satellogic.com/api-token-auth/'
    uname=config.get('satellogic','user_name')
    passw=config.get('satellogic','user_password')
    payload = {'username':uname,'password':passw}
    r = requests.post(url, data=payload)
    if r.status_code != 200:
        raise ValueError("Telluric response error: %s" %r.text)
    telluric_token="JWT "+r.json()['token']
    with open(os.path.join(expanduser("~"),".satellogic-config"),'w') as cfgfile:
        Config.add_section('satellogic')
        Config.set('satellogic','user_name',uname)
        Config.set('satellogic','user_password', passw)
        Config.add_section('token')
        Config.set('token','access_token',telluric_token)
        Config.write(cfgfile)
        cfgfile.close()
    print('Satellogic Access token saved')
    with open(os.path.join(expanduser("~"),".gbdx-config"),'r') as cfgfile:
        config.readfp(cfgfile)
        config.remove_section('gbdx_token')
        config.remove_section('satellogic')
        config.remove_section('token')
    with open(os.path.join(expanduser("~"),".gbdx-config"),'w') as cfgfile:
        config.write(cfgfile)
except Exception as e:
    print(e)

try:
    gbdx=Interface()
    print('GBDX Authenticated')
except Exception as e:
    print(e)



import os
import sys
import setuptools
from setuptools import find_packages
from setuptools.command.test import test as TestCommand
from distutils.version import StrictVersion
from setuptools import __version__ as setuptools_version

if StrictVersion(setuptools_version) < StrictVersion('38.3.0'):
    raise SystemExit(
        'Your `setuptools` version is old. '
        'Please upgrade setuptools by running `pip install -U setuptools` '
        'and try again.'
    )
def readme():
    with open('README.md') as f:
        return f.read()
setuptools.setup(
    name='satadd',
    version='0.0.4',
    packages=find_packages(),
    url='https://github.com/samapriya/satadd',
    install_requires=['gbdxtools>=0.15.12','planet>=1.1.0','geopandas>=0.4.0','requests>=2.19.1',
                      'geojson>=2.4.0','earthengine-api>=0.1.146','gitpython>=2.1.11','pendulum>=2.0.2','Pygments>=2.2.0'],
    license='Apache 2.0',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=(
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Natural Language :: English',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Operating System :: OS Independent',
        'Topic :: Scientific/Engineering :: GIS',
    ),
    author='Samapriya Roy',
    author_email='samapriya.roy@gmail.com',
    description='Simple CLI for piping Planet, Satellogic, GEE & GBDX Assets',
    entry_points={
        'console_scripts': [
            'satadd=satadd.satadd:main',
        ],
    },
)



#!/usr/bin/python
# -*- coding: utf-8 -*-

import argparse
import os
import glob
import sys
import subprocess
from gbdx_validate import validate
from simplesearch import search
from gbdx_mexport import mxp
from gbdx_fpexport import fxp
from satellogic_imagery import satfile
from satellogic_metadata import satmeta
from satellogic_metalist import metalist
from satellogic_bandlist import bandlist
from multiproc_pydl import funct
from batchreproject import reproject
from cli_metadata import metadata
from async_download import ddownload
from idsearch import idsearch
from bandtypes import imgexp
from export import exp
from exp_report import intersect
from os import linesep
import textwrap as _textwrap
from argparse import RawTextHelpFormatter
os.chdir(os.path.dirname(os.path.realpath(__file__)))
path=os.path.dirname(os.path.realpath(__file__))
sys.path.insert(0, path)

def planet_key_entry(args):
    if args.type=="quiet":
        write_planet_json({'key': args.key})
    elif args.type==None and args.key==None:
        try:
            subprocess.call('planet init',shell=True)
        except Exception as e:
            print('Failed to Initialize')

def dginit():
    subprocess.call('python authenticator.py', shell=True)
def dginit_from_parser(args):
    dginit()

def satinit():
    subprocess.call('python satellogic_auth.py', shell=True)
def satinit_from_parser(args):
    satinit()

def eeinit():
    subprocess.call('earthengine authenticate', shell=True)
def eeinit_from_parser(args):
    eeinit()

def credrefresh():
    subprocess.call('python config_refresh.py', shell=True)
def credrefresh_from_parser(args):
    credrefresh()

def dasync_from_parser(args):
    ddownload(infile=args.infile,
           item=args.item,
           asset=args.asset,
           start=args.start,
           end=args.end,
           cmin=args.cmin,
           cmax=args.cmax,
           dirc=args.local)

def savedsearch_from_parser(args):
    if args.limit==None:
        subprocess.call("python saved_search_download.py "+args.name+' '+args.asset+' '+args.local,shell=True)
    else:
        subprocess.call("python saved_search_download.py "+args.name+' '+args.asset+' '+args.local+' '+args.limit,shell=True)

def metadata_from_parser(args):
    metadata(asset=args.asset,mf=args.mf,mfile=args.mfile,errorlog=args.errorlog,directory=args.dir)

def info_from_parser(args):
    validate()

def simple_search_from_parser(args):
    search(path=args.local,
              start=args.start,
              end=args.end,
              limit=int(args.limit))
def metadata_from_parser(args):
    mxp(path=args.local,
              start=args.start,
              end=args.end,
              limit=int(args.limit))

def footprint_from_parser(args):
    fxp(path=args.local,
              dir=args.dirc,
              output=args.output)

def satraster_from_parser(args):
    satfile(sensor=args.sensor,
        geometry=args.geometry,
        target=args.local)

def satlist_from_parser(args):
    bandlist(sensor=args.sensor,
        geometry=args.geometry,
        target=args.local)

def multiproc_from_parser(args):
    subprocess.call("python multiproc_pydl.py "+args.bandlist+" "+args.local,shell=True)

def satmeta_from_parser(args):
    satmeta(sensor=args.sensor,
        geometry=args.geometry,
        target=args.local)

def metalist_from_parser(args):
    metalist(sensor=args.sensor,
        geometry=args.geometry,
        target=args.local)

def reproject_from_parser(args):
    reproject(dest=args.input,
        output=args.output,
        epsg=args.epsg)

def eerefresh():
    filelist = glob.glob(os.path.join(path, "*.csv"))
    for f in filelist:
        os.remove(f)
    subprocess.call('python ee_rep.py', shell=True)
    subprocess.call('python gitcl.py', shell=True)


def eerefresh_from_parser(args):
    eerefresh()


def idsearch_from_parser(args):
    idsearch(mname=args.name)

def intersect_from_parser(args):
    intersect(start=args.start,
              end=args.end,
              geojson=args.aoi,
              operator=args.operator,
              output=args.report)

def imgexp_from_parser(args):
    imgexp(collection=args.id)


def exp_from_parser(args):
    exp(
        collection=args.id,
        folderpath=args.folder,
        typ=args.type,
        start=args.start,
        end=args.end,
        bandnames=args.bandlist,
        geojson=args.aoi,
        operator=args.operator,
        )

spacing = '                               '

def main(args=None):
    parser = argparse.ArgumentParser(description='Simple CLI for piping Planet, Satellogic,GEE & GBDX Assets', formatter_class=argparse.RawTextHelpFormatter)

    subparsers = parser.add_subparsers()
    parser_planet_key = subparsers.add_parser('planetkey', help='Setting up planet API Key')
    optional_named = parser_planet_key.add_argument_group('Optional named arguments')
    optional_named.add_argument('--type', help='For direct key entry type --type quiet')
    optional_named.add_argument('--key', help='Your Planet API Key')
    parser_planet_key.set_defaults(func=planet_key_entry)

    parser_dginit = subparsers.add_parser('dginit',help='Initialize Digital Globe GBDX')
    parser_dginit.set_defaults(func=dginit_from_parser)

    parser_satinit = subparsers.add_parser('satinit',help='Initialize Satellogic Tokens')
    parser_satinit.set_defaults(func=satinit_from_parser)

    parser_eeinit = subparsers.add_parser('eeinit',help='''Initialize Google Earth Engine''')
    parser_eeinit.set_defaults(func=eeinit_from_parser)

    parser_credrefresh = subparsers.add_parser('credrefresh',help='''Refresh Satellogic & GBDX tokens

        ''')
    parser_credrefresh.set_defaults(func=credrefresh_from_parser)

    parser_dasync=subparsers.add_parser('dasync',help='''Uses the Planet Client Async Downloader to download Planet Assets: Does not require activation''')
    parser_dasync.add_argument('--infile',help='Choose a geojson from geojson.io or the aoi-json you created earlier using ppipe aoijson')
    parser_dasync.add_argument('--item',help='Choose from Planet Item types Example: PSScene4Band, PSOrthoTile, REOrthoTile etc')
    parser_dasync.add_argument('--asset',help='Choose an asset type example: anlaytic, analytic_dn,analytic_sr,analytic_xml etc')
    parser_dasync.add_argument('--local',help='Local Path where Planet Item and asset types are saved')
    optional_named = parser_dasync.add_argument_group('Optional named arguments')
    optional_named.add_argument('--start', help='Start date filter format YYYY-MM-DD',default=None)
    optional_named.add_argument('--end', help='End date filter format YYYY-MM-DD',default=None)
    optional_named.add_argument('--cmin', help='Cloud cover minimum between 0-1',default=None)
    optional_named.add_argument('--cmax', help='Cloud cover maximum between 0-1',default=None)
    parser_dasync.set_defaults(func=dasync_from_parser)

    parser_savedsearch=subparsers.add_parser('savedsearch',help='Tool to download saved searches from Planet Explorer')
    parser_savedsearch.add_argument('--name',help='Name of your saved search(It is case sensitive)')
    parser_savedsearch.add_argument('--asset',help='Choose asset type analytic, analytic_xml, analytic_sr, analytic_dn etc')
    parser_savedsearch.add_argument('--local',help='Local Path (full path address) where PlanetAssets are saved')
    optional_named = parser_savedsearch.add_argument_group('Optional named arguments')
    optional_named.add_argument('--limit', help='Choose number of assets you want to download')
    parser_savedsearch.set_defaults(func=savedsearch_from_parser)

    parser_metadata=subparsers.add_parser('metadata',help='''Tool to tabulate and convert all metadata files from Planet
Item and Asset types for Ingestion into GEE

        ''')
    parser_metadata.add_argument('--asset', help='Choose PS OrthoTile(PSO)|PS OrthoTile DN(PSO_DN)|PS OrthoTile Visual(PSO_V)|PS4Band Analytic(PS4B)|PS4Band DN(PS4B_DN)|PS4Band SR(PS4B_SR)|PS3Band Analytic(PS3B)|PS3Band DN(PS3B_DN)|PS3Band Visual(PS3B_V)|RE OrthoTile (REO)|RE OrthoTile Visual(REO_V)|DigitalGlobe MultiSpectral(DGMS)|DigitalGlobe Panchromatic(DGP)|PolarGeospatial CenterDEM Strip(PGCDEM)?')
    parser_metadata.add_argument('--mf', help='Metadata folder?')
    parser_metadata.add_argument('--mfile',help='Metadata filename to be exported along with Path.csv')
    parser_metadata.add_argument('--errorlog',default='./errorlog.csv',help='Errorlog to be exported along with Path.csv')
    optional_named = parser_metadata.add_argument_group('Optional named arguments')
    optional_named.add_argument('--dir', help='Path to Image Directory to be used to get ImageTags with metadata. use only with PS4B_SR')
    parser_metadata.set_defaults(func=metadata_from_parser)

    parser_simple_search = subparsers.add_parser('simple_search',help='Simple search to look for DG assets that intersect your AOI handles KML/SHP/GEOJSON')
    parser_simple_search.add_argument('--local',help='full path for folder or file with SHP/KML/GEOJSON')
    parser_simple_search.add_argument('--start',help='start date YYYY-MM-DD')
    parser_simple_search.add_argument('--end',help='end date YYYY-MM-DD')
    parser_simple_search.add_argument('--limit',help='Limit the number of items to search')
    parser_simple_search.set_defaults(func=simple_search_from_parser)

    parser_metadata = subparsers.add_parser('metadata',help='''Exports metadata for simple search into constitutent folders as JSON files''')
    parser_metadata.add_argument('--local',help='full path for folder or file with SHP/KML/GEOJSON')
    parser_metadata.add_argument('--start',help='start date YYYY-MM-DD')
    parser_metadata.add_argument('--end',help='end date YYYY-MM-DD')
    parser_metadata.add_argument('--limit',help='Limit the number of items to search')
    parser_metadata.set_defaults(func=metadata_from_parser)

    parser_footprint = subparsers.add_parser('footprint',help='''Exports footprint for metadata files extracted earlier'''+
    linesep+"and converts them to individual geometries (GeoJSON)and combined geometry (GeoJSON) file"+'''

    ''')
    parser_footprint.add_argument('--local',help='full path for folder with metadata JSON files')
    parser_footprint.add_argument('--dirc',help='directory to store individual geometries')
    parser_footprint.add_argument('--output',help="path to combined footprint geometry geojson")
    parser_footprint.set_defaults(func=footprint_from_parser)

    parser_satraster = subparsers.add_parser('satraster',help='''Filter and download Satellogic Imagery''')
    parser_satraster.add_argument('--sensor',help='Choose micro or macro depending on multispec or hyperspectal')
    parser_satraster.add_argument('--local',help='Local Path to save files')
    optional_named = parser_satraster.add_argument_group('Optional named arguments')
    optional_named.add_argument('--geometry',help='''Pass GeoJSON geometry file as filter''')
    parser_satraster.set_defaults(func=satraster_from_parser)

    parser_satlist = subparsers.add_parser('satlist',help='''Get url for band list based on filtered Satellogic Imagery''')
    parser_satlist.add_argument('--sensor',help='Choose micro or macro depending on multispec or hyperspectal')
    parser_satlist.add_argument('--local',help='Full path to csv file to save urls')
    optional_named = parser_satlist.add_argument_group('Optional named arguments')
    optional_named.add_argument('--geometry',help='''Pass GeoJSON geometry file as filter''',default=None)
    parser_satlist.set_defaults(func=satlist_from_parser)

    parser_multiproc = subparsers.add_parser('multiproc',help='''Multiprocess based downloader based on satlist''')
    parser_multiproc.add_argument('--bandlist',help='Choose the earlier bandlist that you created')
    parser_multiproc.add_argument('--local',help='Local Path to save files')
    parser_multiproc.set_defaults(func=multiproc_from_parser)

    parser_satmeta = subparsers.add_parser('satmeta',help='''Filter and download Satellogic Metadata''')
    parser_satmeta.add_argument('--sensor',help='Choose micro or macro depending on multispec or hyperspectal')
    parser_satmeta.add_argument('--local',help='Local Path to save files')
    optional_named = parser_satmeta.add_argument_group('Optional named arguments')
    optional_named.add_argument('--geometry',help='''Pass GeoJSON geometry file as filter''')
    parser_satmeta.set_defaults(func=satmeta_from_parser)

    parser_metalist = subparsers.add_parser('metalist',help='''Generates Basic Metadata list per scene for Satellogic Imagery''')
    parser_metalist.add_argument('--sensor',help='Choose micro or macro depending on multispec or hyperspectal')
    parser_metalist.add_argument('--local',help='Local full Path to csv files')
    optional_named = parser_metalist.add_argument_group('Optional named arguments')
    optional_named.add_argument('--geometry',help='Pass GeoJSON geometry file as filter')
    parser_metalist.set_defaults(func=metalist_from_parser)

    parser_reproject = subparsers.add_parser('reproject',help='''Batch reproject rasters using EPSG code

        ''')
    parser_reproject.add_argument('--input',help='Input folder with raster files')
    parser_reproject.add_argument('--output',help='Output folder for reprojected files to be stored')
    parser_reproject.add_argument('--epsg',help='EPSG Code for example 4326')
    parser_reproject.set_defaults(func=reproject_from_parser)

    parser_eerefresh = subparsers.add_parser('eerefresh',help='Refreshes your personal asset list and GEE Asset list')
    parser_eerefresh.set_defaults(func=eerefresh_from_parser)

    parser_idsearch = subparsers.add_parser('idsearch',help='Does possible matches using asset name to give you asseth id/full path')
    parser_idsearch.add_argument('--name',help='Name or part of name to search for')
    parser_idsearch.set_defaults(func=idsearch_from_parser)


    parser_intersect = subparsers.add_parser('intersect',help='Exports a report of all assets(Personal & GEE) intersecting with provided geometry')
    parser_intersect.add_argument('--start',help='Start date to filter image',default=None)
    parser_intersect.add_argument('--end', help='End date to filter image', default=None)
    parser_intersect.add_argument('--aoi',help='Full path to geojson/json/kml to be used for bounds')
    parser_intersect.add_argument('--report',help='Full path where the report will be exported including type, path & number of intersects', default=None)
    optional_named = parser_intersect.add_argument_group('Optional named arguments for geometry only')
    optional_named.add_argument('--operator',help='Use bb for Bounding box incase the geometry is complex or has too many vertices', default=None)
    parser_intersect.set_defaults(func=intersect_from_parser)

    parser_imgexp = subparsers.add_parser('bandtype',help='Prints GEE bandtype and generates list to be used for export')
    parser_imgexp.add_argument('--id',help='full path for collection or image')
    parser_imgexp.set_defaults(func=imgexp_from_parser)

    parser_exp = subparsers.add_parser('export',help='Export GEE Collections based on filter')
    parser_exp.add_argument('--id',help='Full path for collection or image')
    parser_exp.add_argument('--folder', help='Drive folder path')
    parser_exp.add_argument('--type',help='Type whether image or collection')
    parser_exp.add_argument('--aoi',help='Full path to geojson/json/kml to be used for bounds')
    optional_named = parser_exp.add_argument_group('Optional named arguments for image collection only')
    optional_named.add_argument('--start',help='Start date to filter image',default=None)
    optional_named.add_argument('--end', help='End date to filter image', default=None)
    optional_named.add_argument('--bandlist',help='Bandlist we generated from bandtype export must be same bandtype', default=None)
    optional_named.add_argument('--operator',help='Use bb for Bounding box incase the geometry is complex or has too many vertices', default=None)
    parser_exp.set_defaults(func=exp_from_parser)

    args = parser.parse_args()
    args.func(args)


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-
import json
import os
import shapely.wkt
import shapely.geometry
os.chdir(os.path.dirname(os.path.realpath(__file__)))


# Function to merge geojson into one

def mergeFile(local, dir, output):
    fc = {'type': 'FeatureCollection', 'features': []}
    for items in os.listdir(dir):
        if items.endswith('.geojson'):
            f = open(os.path.join(local, items))
            for line in f:
                obj = json.loads(line)
                fc['features'].extend(obj['features'])

            # print(json.dumps(fc))

            with open(os.path.join(local, str(output)), 'w') as outfile:
                json.dump(fc, outfile)
    print('Combined Geojson Exported at '+str(output))

# Function to extract and convert WKT footprint to geojsons

def fxp(path, dir, output):
    base = {'type': 'FeatureCollection', 'features': [{'type': 'Feature'
            , 'properties': {}, 'geometry': {'type': 'Polygon',
            'coordinates': []}}]}
    fc = {'type': 'FeatureCollection', 'features': []}
    for items in os.listdir(path):
        if items.endswith('.json'):
            f = open(os.path.join(path, items))
            for line in f:
                obj = json.loads(line)
                s = obj['footprintWkt']
                g1 = shapely.wkt.loads(s)
                g2 = shapely.geometry.mapping(g1)
                form = json.dumps(g2)
                a = json.dumps(g2).replace('[[[[', '[[[').replace(']]]]'
                        , ']]]')
                base['features'][0]['geometry']['coordinates'] = \
                    json.loads(a)['coordinates']
                with open(os.path.join(dir, str(items).replace('.json',
                          '.geojson')), 'w') as outfile:
                    json.dump(base, outfile)
    print('Geojson Exports Complete at '+str(dir))
    mergeFile(local=path, dir=dir, output=output)

# fxp(path=r'C:\planet_demo\imja\LANDSAT08', dir=r'C:\planet_demo\imja\ge'
#     , output=r'C:\planet_demo\imja\l8.geojson')



import configparser
import requests
import json
import os
import getpass
import csv
from os.path import expanduser
from multipath import shp2cord
from multipath import shp2cordfile
os.chdir(os.path.dirname(os.path.realpath(__file__)))
url = "https://geobigdata.io/catalog/v2/search"
config=configparser.ConfigParser()

def search(path,start,end,limit):
    try:
        config.read(os.path.join(expanduser("~"),".gbdx-config"))
        at=json.loads(config.get('gbdx_token','json'))
        accesstoken=at['access_token']
        start=str(start)+str('T12:00:00.000Z')
        end=str(end)+str('T12:00:00.000Z')
        if os.path.isfile(path):
            cd=shp2cordfile(path)
            payload= {"searchAreaWkt": cd,"startDate": start,"endDate": end,"limit":limit}
            payload=json.dumps(payload)
            headers = {
                'Content-Type': "application/json",
                'Authorization': "Bearer "+accesstoken,
                }
            response = requests.request("POST", url, data=payload, headers=headers).json()
            for key,value in response['stats']['typeCounts'].items():
                print(str(key)+' '+str(value))
        elif os.path.isdir(path):
            ext = [".geojson", ".shp", ".kml", ".json"]
            for things in os.listdir(path):
                if things.endswith(tuple(ext)):
                    cd=shp2cordfile(os.path.join(path,things))
                    print('')
                    print('Searching DG assets for '+str(things))
                    payload= {"searchAreaWkt": cd,"startDate": start,"endDate": end,"types":["DigitalGlobeProduct"],"limit":limit}
                    payload=json.dumps(payload)
                    headers = {
                        'Content-Type': "application/json",
                        'Authorization': "Bearer "+accesstoken,
                        }
                    response = requests.request("POST", url, data=payload, headers=headers).json()
                    for key,value in response['stats']['typeCounts'].items():
                        print(str(key)+' : '+str(value))
    except Exception as e:
        print('access_token not found')
        subprocess.call('python autenticator.py', shell=True)
# search(path=r'C:\Users\samapriya\Box Sync\IUB\Paper Discussions\Deltas Project Edmond NSF 2016\Analysis\Fishnet-Grid\grid_split',start='2016-01-01',end='2018-01-01',limit=125)



import os

def reproject(dest,output,epsg):
    for root, dirs, files in os.walk(dest, topdown=False):
        [head,tail]=os.path.split(root)
        destfold=output
        if not os.path.isdir(destfold):
            os.makedirs(destfold)
            print("Creating folder "+str(destfold))
        try:
            for items in os.listdir(root):
                if items.endswith('.tif'):
                    print('Processing Rasters in '+str(root))
                    base=os.path.join(root,items)
                    target=os.path.join(destfold,items)
                    os.system('gdalwarp -t_srs EPSG:'+str(epsg)+' '+base+' '+target)
        except Exception as e:
            print(e)
#4326
